## v1.0.0a2

- 修复 `paicorelib` 错误的导入与版本约依赖

## v1.0.0a3

- 添加示例
- 修复工作流版本错误
- 修复神经元膜电位溢出处理错误
- 修复神经元分组的计数错误

## v1.0.0a4

- 重命名突触连接类型 `ConnType` 为 `SynConnType` ，现在通过 `pb.SynCnnType.x` 调用。例如，`pb.SynCnnType.All2All`

## v1.0.0a5

- 支持无限嵌套深度的网络
- 支持全展开2D卷积算子构建与部署（`padding` 不支持）
- 修复当 `keep_shape=True` 时，神经元状态变量在运行时尺寸错误

## v1.0.0a6

- 新增 `Always1Neuron` 神经元，该神经元将在工作期间持续输出1，不得单独存在，需存在前向突触与其连接

## v1.0.0a7

- 支持全展开1D卷积算子构建与部署（`padding` 不支持）

## v1.0.0b1

- 提高 `numpy` 依赖版本至 `^1.24.0`
- 修复神经元输入累加错误
- 修复当权重为 `np.bool_` 且关闭权重精度优化选项( `weight_bit_optimization` )后，仍视为 `np.int8` 的错误
- 支持混合精度权重的部署

## v1.0.0rc1

- 支持全展开1D/2D转置卷积算子。所有的卷积算子均支持 `padding`
- 新增直接编码器
- 修复后端的一些错误

## v1.0.0

- 提高 `paicorelib` 依赖版本至 `^1.0.0`
- 当出现重名 `paibox.PAIBoxObject` 时将自动修改名称进行规避
- 完善测试ci

## v1.1.0

- 移除 Python 3.8 支持
- 提高 `paicorelib` 依赖版本至 `^1.1.6`
- 提高 `pydantic` 依赖版本至 `^2.0.3`
- 新增功能模块：支持逻辑与、或、非、异或，脉冲加、减、2D平均/最大池化、2D矩阵乘法等算子
- IF/LIF 功能支持

  1. 软重置、硬重置模式
  2. 负阈值，默认为硬件允许的最小负整数
  3. LIF 支持设置偏置，偏置可为数组形式
  4. LIF 支持同时设置泄漏与偏置，将叠加处理

- 支持神经元的随机突触整合、随机阈值、随机泄露配置的设置，但不支持仿真
- 支持多芯片部署
- 重构路由算法，现在路由不会出现死锁
- 行为变更：

  1. 子网络现在直接在主网络内部 `self.subnet=...` 例化即可
  2. 编译选项现在直接通过 `paibox.Mapper.compile(...)` 传入，默认配置不变
  3. 在 `paibox.Mapper.export()` 中通过 `split_by_chip` 选项指定配置帧文件是否以芯片分割，默认不分割。原 `split_by_coord` 选项移除

## v1.1.1

- 修复对权重 RAM 错误的配置

## v1.2.0a1

- 提高 `paicorelib` 依赖版本至 `~1.3`
- 支持 ANN 网络的构建与部署

## v1.2.0a2

- 提高 `paicorelib` 依赖版本至 `>=1.3.1`
- 支持1D脉冲平均/最大池化算子
- 重构路由算法，支持嵌套路由

## v1.2.0

- 支持 ANN 模式下半折叠算子的构建与部署
- 支持分组卷积，包括 SNN、全展开形式与半折叠形式卷积
- 优化后端构建网络的流程
- 修复当在编译时开启 `core_estimate_only` 选项后导出时将报错的错误。现在在开启此选项后无法导出
- 修复了编译后网络的属性 `inherent_timestep` （即第一次输出有效计算结果的时刻）错误的计算方法。现在将通过标注数据流格式的方式计算得到该属性

## v1.2.1

- 为硬件平台提供基准版本运行时
- 新增日志系统
- 支持 ANN 模式下 1d/2d 平均/最大池化算子
- `paibox.Mapper.compile()` 移除 `export_core_params` 配置项。由于硬件平台会使用计算核配置信息，因此默认导出
- 支持单个输出节点数目大于1152
- 输出数据流格式信息将导出至编译后图信息内
